summaryrefslogtreecommitdiffstats
path: root/content/browser/android/touch_point.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/browser/android/touch_point.h')
-rw-r--r--content/browser/android/touch_point.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/content/browser/android/touch_point.h b/content/browser/android/touch_point.h
index 8e9971ba..d7caac0 100644
--- a/content/browser/android/touch_point.h
+++ b/content/browser/android/touch_point.h
@@ -12,7 +12,7 @@
namespace content {
// This class provides a helper method to convert a java object array of touch
// events (in physical pixdels) into a WebKit::WebTouchEvent (in dip).
class TouchPoint {
public:
static void BuildWebTouchEvent(JNIEnv* env,
@@ -20,7 +20,7 @@ class TouchPoint {
jlong time_ms,
float dpi_scale,
jobjectArray pts,
- WebKit::WebTouchEvent& event);
+ blink::WebTouchEvent& event);
};
bool RegisterTouchPoint(JNIEnv* env);
@@ -12,7 +12,7 @@
namespace content {
// This class provides a helper method to convert a java object array of touch
-// events (in physical pixdels) into a WebKit::WebTouchEvent (in dip).
+// events (in physical pixdels) into a blink::WebTouchEvent (in dip).
class TouchPoint {
public: